# SPDX-License-Identifier: MIT
# Copyright (C) 2018-present iced project and contributors

# ⚠️This file was generated by GENERATOR!🦹‍♂️

# pylint: disable=invalid-name
# pylint: disable=line-too-long
# pylint: disable=too-many-lines

"""
Operand kind
"""

NONE: int = 0
"""
No operand
"""
FARBR2_2: int = 1
"""
Far branch 16-bit offset, 16-bit segment/selector
"""
FARBR4_2: int = 2
"""
Far branch 32-bit offset, 16-bit segment/selector
"""
MEM_OFFS: int = 3
"""
Memory offset without a modrm byte (eg. ``MOV AL,[offset]``)
"""
MEM: int = 4
"""
Memory (modrm)
"""
MEM_MPX: int = 5
"""
: Memory (modrm), MPX:

16/32-bit mode: must be 32-bit addressing

64-bit mode: 64-bit addressing is forced and must not be RIP relative
"""
MEM_MIB: int = 6
"""
: Memory (modrm), MPX:

16/32-bit mode: must be 32-bit addressing

64-bit mode: 64-bit addressing is forced and must not be RIP relative
"""
MEM_VSIB32X: int = 7
"""
Memory (modrm), vsib32, ``XMM`` registers
"""
MEM_VSIB64X: int = 8
"""
Memory (modrm), vsib64, ``XMM`` registers
"""
MEM_VSIB32Y: int = 9
"""
Memory (modrm), vsib32, ``YMM`` registers
"""
MEM_VSIB64Y: int = 10
"""
Memory (modrm), vsib64, ``YMM`` registers
"""
MEM_VSIB32Z: int = 11
"""
Memory (modrm), vsib32, ``ZMM`` registers
"""
MEM_VSIB64Z: int = 12
"""
Memory (modrm), vsib64, ``ZMM`` registers
"""
R8_OR_MEM: int = 13
"""
8-bit GPR or memory
"""
R16_OR_MEM: int = 14
"""
16-bit GPR or memory
"""
R32_OR_MEM: int = 15
"""
32-bit GPR or memory
"""
R32_OR_MEM_MPX: int = 16
"""
: 32-bit GPR or memory, MPX: 16/32-bit mode: must be 32-bit addressing, 64-bit mode: 64-bit addressing is forced
"""
R64_OR_MEM: int = 17
"""
64-bit GPR or memory
"""
R64_OR_MEM_MPX: int = 18
"""
: 64-bit GPR or memory, MPX: 16/32-bit mode: must be 32-bit addressing, 64-bit mode: 64-bit addressing is forced
"""
MM_OR_MEM: int = 19
"""
``MM`` register or memory
"""
XMM_OR_MEM: int = 20
"""
``XMM`` register or memory
"""
YMM_OR_MEM: int = 21
"""
``YMM`` register or memory
"""
ZMM_OR_MEM: int = 22
"""
``ZMM`` register or memory
"""
BND_OR_MEM_MPX: int = 23
"""
: ``BND`` register or memory, MPX: 16/32-bit mode: must be 32-bit addressing, 64-bit mode: 64-bit addressing is forced
"""
K_OR_MEM: int = 24
"""
``K`` register or memory
"""
R8_REG: int = 25
"""
8-bit GPR encoded in the ``reg`` field of the modrm byte
"""
R8_OPCODE: int = 26
"""
8-bit GPR encoded in the low 3 bits of the opcode
"""
R16_REG: int = 27
"""
16-bit GPR encoded in the ``reg`` field of the modrm byte
"""
R16_REG_MEM: int = 28
"""
16-bit GPR encoded in the ``reg`` field of the modrm byte. This is a memory operand and it uses the address size prefix (``67h``) not the operand size prefix (``66h``).
"""
R16_RM: int = 29
"""
16-bit GPR encoded in the ``mod + r/m`` fields of the modrm byte
"""
R16_OPCODE: int = 30
"""
16-bit GPR encoded in the low 3 bits of the opcode
"""
R32_REG: int = 31
"""
32-bit GPR encoded in the ``reg`` field of the modrm byte
"""
R32_REG_MEM: int = 32
"""
32-bit GPR encoded in the ``reg`` field of the modrm byte. This is a memory operand and it uses the address size prefix (``67h``) not the operand size prefix (``66h``).
"""
R32_RM: int = 33
"""
32-bit GPR encoded in the ``mod + r/m`` fields of the modrm byte
"""
R32_OPCODE: int = 34
"""
32-bit GPR encoded in the low 3 bits of the opcode
"""
R32_VVVV: int = 35
"""
32-bit GPR encoded in the the ``V'vvvv`` field (VEX/EVEX/XOP)
"""
R64_REG: int = 36
"""
64-bit GPR encoded in the ``reg`` field of the modrm byte
"""
R64_REG_MEM: int = 37
"""
64-bit GPR encoded in the ``reg`` field of the modrm byte. This is a memory operand and it uses the address size prefix (``67h``) not the operand size prefix (``66h``).
"""
R64_RM: int = 38
"""
64-bit GPR encoded in the ``mod + r/m`` fields of the modrm byte
"""
R64_OPCODE: int = 39
"""
64-bit GPR encoded in the low 3 bits of the opcode
"""
R64_VVVV: int = 40
"""
64-bit GPR encoded in the the ``V'vvvv`` field (VEX/EVEX/XOP)
"""
SEG_REG: int = 41
"""
Segment register encoded in the ``reg`` field of the modrm byte
"""
K_REG: int = 42
"""
``K`` register encoded in the ``reg`` field of the modrm byte
"""
KP1_REG: int = 43
"""
``K`` register (+1) encoded in the ``reg`` field of the modrm byte
"""
K_RM: int = 44
"""
``K`` register encoded in the ``mod + r/m`` fields of the modrm byte
"""
K_VVVV: int = 45
"""
``K`` register encoded in the the ``V'vvvv`` field (VEX/EVEX/XOP)
"""
MM_REG: int = 46
"""
``MM`` register encoded in the ``reg`` field of the modrm byte
"""
MM_RM: int = 47
"""
``MM`` register encoded in the ``mod + r/m`` fields of the modrm byte
"""
XMM_REG: int = 48
"""
``XMM`` register encoded in the ``reg`` field of the modrm byte
"""
XMM_RM: int = 49
"""
``XMM`` register encoded in the ``mod + r/m`` fields of the modrm byte
"""
XMM_VVVV: int = 50
"""
``XMM`` register encoded in the the ``V'vvvv`` field (VEX/EVEX/XOP)
"""
XMMP3_VVVV: int = 51
"""
``XMM`` register (+3) encoded in the the ``V'vvvv`` field (VEX/EVEX/XOP)
"""
XMM_IS4: int = 52
"""
``XMM`` register encoded in the the high 4 bits of the last 8-bit immediate (VEX/XOP only so only ``XMM0``-``XMM15``)
"""
XMM_IS5: int = 53
"""
``XMM`` register encoded in the the high 4 bits of the last 8-bit immediate (VEX/XOP only so only ``XMM0``-``XMM15``)
"""
YMM_REG: int = 54
"""
``YMM`` register encoded in the ``reg`` field of the modrm byte
"""
YMM_RM: int = 55
"""
``YMM`` register encoded in the ``mod + r/m`` fields of the modrm byte
"""
YMM_VVVV: int = 56
"""
``YMM`` register encoded in the the ``V'vvvv`` field (VEX/EVEX/XOP)
"""
YMM_IS4: int = 57
"""
``YMM`` register encoded in the the high 4 bits of the last 8-bit immediate (VEX/XOP only so only ``YMM0``-``YMM15``)
"""
YMM_IS5: int = 58
"""
``YMM`` register encoded in the the high 4 bits of the last 8-bit immediate (VEX/XOP only so only ``YMM0``-``YMM15``)
"""
ZMM_REG: int = 59
"""
``ZMM`` register encoded in the ``reg`` field of the modrm byte
"""
ZMM_RM: int = 60
"""
``ZMM`` register encoded in the ``mod + r/m`` fields of the modrm byte
"""
ZMM_VVVV: int = 61
"""
``ZMM`` register encoded in the the ``V'vvvv`` field (VEX/EVEX/XOP)
"""
ZMMP3_VVVV: int = 62
"""
``ZMM`` register (+3) encoded in the the ``V'vvvv`` field (VEX/EVEX/XOP)
"""
CR_REG: int = 63
"""
``CR`` register encoded in the ``reg`` field of the modrm byte
"""
DR_REG: int = 64
"""
``DR`` register encoded in the ``reg`` field of the modrm byte
"""
TR_REG: int = 65
"""
``TR`` register encoded in the ``reg`` field of the modrm byte
"""
BND_REG: int = 66
"""
``BND`` register encoded in the ``reg`` field of the modrm byte
"""
ES: int = 67
"""
``ES`` register
"""
CS: int = 68
"""
``CS`` register
"""
SS: int = 69
"""
``SS`` register
"""
DS: int = 70
"""
``DS`` register
"""
FS: int = 71
"""
``FS`` register
"""
GS: int = 72
"""
``GS`` register
"""
AL: int = 73
"""
``AL`` register
"""
CL: int = 74
"""
``CL`` register
"""
AX: int = 75
"""
``AX`` register
"""
DX: int = 76
"""
``DX`` register
"""
EAX: int = 77
"""
``EAX`` register
"""
RAX: int = 78
"""
``RAX`` register
"""
ST0: int = 79
"""
``ST(0)`` register
"""
STI_OPCODE: int = 80
"""
``ST(i)`` register encoded in the low 3 bits of the opcode
"""
IMM4_M2Z: int = 81
"""
4-bit immediate (m2z field, low 4 bits of the /is5 immediate, eg. ``VPERMIL2PS``)
"""
IMM8: int = 82
"""
8-bit immediate
"""
IMM8_CONST_1: int = 83
"""
Constant 1 (8-bit immediate)
"""
IMM8SEX16: int = 84
"""
8-bit immediate sign extended to 16 bits
"""
IMM8SEX32: int = 85
"""
8-bit immediate sign extended to 32 bits
"""
IMM8SEX64: int = 86
"""
8-bit immediate sign extended to 64 bits
"""
IMM16: int = 87
"""
16-bit immediate
"""
IMM32: int = 88
"""
32-bit immediate
"""
IMM32SEX64: int = 89
"""
32-bit immediate sign extended to 64 bits
"""
IMM64: int = 90
"""
64-bit immediate
"""
SEG_RSI: int = 91
"""
``seg:[rSI]`` memory operand (string instructions)
"""
ES_RDI: int = 92
"""
``es:[rDI]`` memory operand (string instructions)
"""
SEG_RDI: int = 93
"""
``seg:[rDI]`` memory operand (``(V)MASKMOVQ`` instructions)
"""
SEG_RBX_AL: int = 94
"""
``seg:[rBX+al]`` memory operand (``XLATB`` instruction)
"""
BR16_1: int = 95
"""
16-bit branch, 1-byte signed relative offset
"""
BR32_1: int = 96
"""
32-bit branch, 1-byte signed relative offset
"""
BR64_1: int = 97
"""
64-bit branch, 1-byte signed relative offset
"""
BR16_2: int = 98
"""
16-bit branch, 2-byte signed relative offset
"""
BR32_4: int = 99
"""
32-bit branch, 4-byte signed relative offset
"""
BR64_4: int = 100
"""
64-bit branch, 4-byte signed relative offset
"""
XBEGIN_2: int = 101
"""
``XBEGIN``, 2-byte signed relative offset
"""
XBEGIN_4: int = 102
"""
``XBEGIN``, 4-byte signed relative offset
"""
BRDISP_2: int = 103
"""
2-byte branch offset (``JMPE`` instruction)
"""
BRDISP_4: int = 104
"""
4-byte branch offset (``JMPE`` instruction)
"""
SIBMEM: int = 105
"""
Memory (modrm) and the sib byte must be present
"""
TMM_REG: int = 106
"""
``TMM`` register encoded in the ``reg`` field of the modrm byte
"""
TMM_RM: int = 107
"""
``TMM`` register encoded in the ``mod + r/m`` fields of the modrm byte
"""
TMM_VVVV: int = 108
"""
``TMM`` register encoded in the the ``V'vvvv`` field (VEX/EVEX/XOP)
"""



# SPDX-License-Identifier: MIT
# Copyright (C) 2018-present iced project and contributors

# ⚠️This file was generated by GENERATOR!🦹‍♂️

# pylint: disable=invalid-name
# pylint: disable=line-too-long
# pylint: disable=too-many-lines

"""
Rounding control
"""

NONE: int = 0
"""
No rounding mode
"""
ROUND_TO_NEAREST: int = 1
"""
Round to nearest (even)
"""
ROUND_DOWN: int = 2
"""
Round down (toward -inf)
"""
ROUND_UP: int = 3
"""
Round up (toward +inf)
"""
ROUND_TOWARD_ZERO: int = 4
"""
Round toward zero (truncate)
"""



# SPDX-License-Identifier: MIT
# Copyright (C) 2018-present iced project and contributors

# ⚠️This file was generated by GENERATOR!🦹‍♂️

# pylint: disable=invalid-name
# pylint: disable=line-too-long
# pylint: disable=too-many-lines

"""
Mnemonic condition code selector (eg. ``JP`` / ``JPE``)
"""

P: int = 0
"""
``JP``, ``CMOVP``, ``SETP``
"""
PE: int = 1
"""
``JPE``, ``CMOVPE``, ``SETPE``
"""



# SPDX-License-Identifier: MIT
# Copyright (C) 2018-present iced project and contributors

# ⚠️This file was generated by GENERATOR!🦹‍♂️

# pylint: disable=invalid-name
# pylint: disable=line-too-long
# pylint: disable=too-many-lines

"""
Instruction operand kind
"""

REGISTER: int = 0
"""
A register (:class:`iced_x86.Register`).

This operand kind uses :class:`iced_x86.Instruction.op0_register`, :class:`iced_x86.Instruction.op1_register`, :class:`iced_x86.Instruction.op2_register`, :class:`iced_x86.Instruction.op3_register` or :class:`iced_x86.Instruction.op4_register` depending on operand number. See also :class:`iced_x86.Instruction.op_register`.
"""
NEAR_BRANCH16: int = 1
"""
Near 16-bit branch. This operand kind uses :class:`iced_x86.Instruction.near_branch16`
"""
NEAR_BRANCH32: int = 2
"""
Near 32-bit branch. This operand kind uses :class:`iced_x86.Instruction.near_branch32`
"""
NEAR_BRANCH64: int = 3
"""
Near 64-bit branch. This operand kind uses :class:`iced_x86.Instruction.near_branch64`
"""
FAR_BRANCH16: int = 4
"""
Far 16-bit branch. This operand kind uses :class:`iced_x86.Instruction.far_branch16` and :class:`iced_x86.Instruction.far_branch_selector`
"""
FAR_BRANCH32: int = 5
"""
Far 32-bit branch. This operand kind uses :class:`iced_x86.Instruction.far_branch32` and :class:`iced_x86.Instruction.far_branch_selector`
"""
IMMEDIATE8: int = 6
"""
8-bit constant. This operand kind uses :class:`iced_x86.Instruction.immediate8`
"""
IMMEDIATE8_2ND: int = 7
"""
8-bit constant used by the ``ENTER``, ``EXTRQ``, ``INSERTQ`` instructions. This operand kind uses :class:`iced_x86.Instruction.immediate8_2nd`
"""
IMMEDIATE16: int = 8
"""
16-bit constant. This operand kind uses :class:`iced_x86.Instruction.immediate16`
"""
IMMEDIATE32: int = 9
"""
32-bit constant. This operand kind uses :class:`iced_x86.Instruction.immediate32`
"""
IMMEDIATE64: int = 10
"""
64-bit constant. This operand kind uses :class:`iced_x86.Instruction.immediate64`
"""
IMMEDIATE8TO16: int = 11
"""
An 8-bit value sign extended to 16 bits. This operand kind uses :class:`iced_x86.Instruction.immediate8to16`
"""
IMMEDIATE8TO32: int = 12
"""
An 8-bit value sign extended to 32 bits. This operand kind uses :class:`iced_x86.Instruction.immediate8to32`
"""
IMMEDIATE8TO64: int = 13
"""
An 8-bit value sign extended to 64 bits. This operand kind uses :class:`iced_x86.Instruction.immediate8to64`
"""
IMMEDIATE32TO64: int = 14
"""
A 32-bit value sign extended to 64 bits. This operand kind uses :class:`iced_x86.Instruction.immediate32to64`
"""
MEMORY_SEG_SI: int = 15
"""
``seg:[SI]``. This operand kind uses :class:`iced_x86.Instruction.memory_size`, :class:`iced_x86.Instruction.memory_segment`, :class:`iced_x86.Instruction.segment_prefix`
"""
MEMORY_SEG_ESI: int = 16
"""
``seg:[ESI]``. This operand kind uses :class:`iced_x86.Instruction.memory_size`, :class:`iced_x86.Instruction.memory_segment`, :class:`iced_x86.Instruction.segment_prefix`
"""
MEMORY_SEG_RSI: int = 17
"""
``seg:[RSI]``. This operand kind uses :class:`iced_x86.Instruction.memory_size`, :class:`iced_x86.Instruction.memory_segment`, :class:`iced_x86.Instruction.segment_prefix`
"""
MEMORY_SEG_DI: int = 18
"""
``seg:[DI]``. This operand kind uses :class:`iced_x86.Instruction.memory_size`, :class:`iced_x86.Instruction.memory_segment`, :class:`iced_x86.Instruction.segment_prefix`
"""
MEMORY_SEG_EDI: int = 19
"""
``seg:[EDI]``. This operand kind uses :class:`iced_x86.Instruction.memory_size`, :class:`iced_x86.Instruction.memory_segment`, :class:`iced_x86.Instruction.segment_prefix`
"""
MEMORY_SEG_RDI: int = 20
"""
``seg:[RDI]``. This operand kind uses :class:`iced_x86.Instruction.memory_size`, :class:`iced_x86.Instruction.memory_segment`, :class:`iced_x86.Instruction.segment_prefix`
"""
MEMORY_ESDI: int = 21
"""
``ES:[DI]``. This operand kind uses :class:`iced_x86.Instruction.memory_size`
"""
MEMORY_ESEDI: int = 22
"""
``ES:[EDI]``. This operand kind uses :class:`iced_x86.Instruction.memory_size`
"""
MEMORY_ESRDI: int = 23
"""
``ES:[RDI]``. This operand kind uses :class:`iced_x86.Instruction.memory_size`
"""
MEMORY: int = 25
"""
Memory operand.

This operand kind uses :class:`iced_x86.Instruction.memory_displ_size`, :class:`iced_x86.Instruction.memory_size`, :class:`iced_x86.Instruction.memory_index_scale`, :class:`iced_x86.Instruction.memory_displacement`, :class:`iced_x86.Instruction.memory_base`, :class:`iced_x86.Instruction.memory_index`, :class:`iced_x86.Instruction.memory_segment`, :class:`iced_x86.Instruction.segment_prefix`
"""



# SPDX-License-Identifier: MIT
# Copyright (C) 2018-present iced project and contributors

# ⚠️This file was generated by GENERATOR!🦹‍♂️

# pylint: disable=invalid-name
# pylint: disable=line-too-long
# pylint: disable=too-many-lines

"""
Opcode table
"""

NORMAL: int = 0
"""
Legacy encoding table
"""
T0F: int = 1
"""
``0Fxx`` table (legacy, VEX, EVEX)
"""
T0F38: int = 2
"""
``0F38xx`` table (legacy, VEX, EVEX)
"""
T0F3A: int = 3
"""
``0F3Axx`` table (legacy, VEX, EVEX)
"""
XOP8: int = 4
"""
``XOP8`` table (XOP)
"""
XOP9: int = 5
"""
``XOP9`` table (XOP)
"""
XOPA: int = 6
"""
``XOPA`` table (XOP)
"""



# SPDX-License-Identifier: MIT
# Copyright (C) 2018-present iced project and contributors

# ⚠️This file was generated by GENERATOR!🦹‍♂️

# pylint: disable=invalid-name
# pylint: disable=line-too-long
# pylint: disable=too-many-lines

"""
Mandatory prefix
"""

NONE: int = 0
"""
No mandatory prefix (legacy and 3DNow! tables only)
"""
PNP: int = 1
"""
Empty mandatory prefix (no ``66``, ``F3`` or ``F2`` prefix)
"""
P66: int = 2
"""
``66`` prefix
"""
PF3: int = 3
"""
``F3`` prefix
"""
PF2: int = 4
"""
``F2`` prefix
"""



# SPDX-License-Identifier: MIT
# Copyright (C) 2018-present iced project and contributors

import copy
import pytest
from iced_x86 import *

def test_eq_ne_hash():
	mem1 = MemoryOperand()
	mem2 = MemoryOperand(Register.NONE, Register.NONE, 1, 0, 0, False, Register.NONE)
	mem3 = MemoryOperand(index=Register.RAX)

	assert mem1 == mem2
	assert not (mem1 != mem2)
	assert hash(mem1) == hash(mem2)

	assert mem1 != mem3
	assert not (mem1 == mem3)

	assert mem1 != 1
	assert mem1 != 1.23
	assert mem1 != None
	assert mem1 != []
	assert mem1 != {}
	assert mem1 != (1, 2)

	assert not (mem1 == 1)
	assert not (mem1 == 1.23)
	assert not (mem1 == None)
	assert not (mem1 == [])
	assert not (mem1 == {})
	assert not (mem1 == (1, 2))

@pytest.mark.parametrize("copy_mem", [
	lambda mem: copy.copy(mem),
	lambda mem: copy.deepcopy(mem),
	lambda mem: mem.copy(),
])
def test_copy_deepcopy_mcopy(copy_mem):
	mem = MemoryOperand(Register.RCX, Register.RDI, 8, 0x1234_5678, 8, True, Register.GS)
	mem2 = copy_mem(mem)
	assert mem is not mem2
	assert id(mem) != id(mem2)

	assert mem == mem2
	assert not (mem != mem2)
	assert hash(mem) == hash(mem2)

def test_ctor():
	mem1 = MemoryOperand(base=Register.RCX, index=Register.ZMM13, scale=2, displ=-0x1234_5678, displ_size=8, is_broadcast=True, seg=Register.FS)
	mem2 = MemoryOperand(seg=Register.FS, is_broadcast=True, displ_size=8, displ=-0x1234_5678, scale=2, index=Register.ZMM13, base=Register.RCX)
	assert mem1 == mem2
	assert not (mem1 != mem2)
	assert hash(mem1) == hash(mem2)

def test_displ_size():
	mem1 = MemoryOperand(Register.EBP, displ=0x1234_5678)

	mem2 = MemoryOperand(Register.EBP, displ=0x1234_5678, displ_size=0)
	assert mem1 == mem2
	assert not (mem1 != mem2)
	assert hash(mem1) == hash(mem2)

	mem2 = MemoryOperand(Register.EBP, displ=0x1234_5678, displ_size=1)
	assert mem1 == mem2
	assert not (mem1 != mem2)
	assert hash(mem1) == hash(mem2)

	mem2 = MemoryOperand(Register.EBP, displ=0x1234_5678, displ_size=4)
	assert mem1 != mem2
	assert not (mem1 == mem2)

@pytest.mark.parametrize("create", [
	lambda: MemoryOperand(base=1234),
	lambda: MemoryOperand(index=1234),
	lambda: MemoryOperand(seg=1234),
])
def test_invalid_reg_enum_arg(create):
	with pytest.raises(ValueError):
		create()



# SPDX-License-Identifier: MIT
# Copyright (C) 2018-present iced project and contributors

# ⚠️This file was generated by GENERATOR!🦹‍♂️

# pylint: disable=invalid-name
# pylint: disable=line-too-long
# pylint: disable=too-many-lines

"""
``REP``/``REPE``/``REPNE`` prefix
"""

NONE: int = 0
"""
No ``REP``/``REPE``/``REPNE`` prefix
"""
REPE: int = 1
"""
``REP``/``REPE`` prefix
"""
REPNE: int = 2
"""
``REPNE`` prefix
"""



# SPDX-License-Identifier: MIT
# Copyright (C) 2018-present iced project and contributors

# ⚠️This file was generated by GENERATOR!🦹‍♂️

# pylint: disable=invalid-name
# pylint: disable=line-too-long
# pylint: disable=too-many-lines

"""
Decoder options
"""

NONE: int = 0x0000_0000
"""
No option is enabled
"""
NO_INVALID_CHECK: int = 0x0000_0001
"""
Disable some checks for invalid encodings of instructions, eg. most instructions can't use a ``LOCK`` prefix so if one is found, they're decoded as :class:`iced_x86.Code.INVALID` unless this option is enabled.
"""
AMD: int = 0x0000_0002
"""
: AMD decoder: allow 16-bit branch/ret instructions in 64-bit mode, no ``o64 CALL/JMP FAR [mem], o64 LSS/LFS/LGS``, ``UD0`` has no modr/m byte, decode ``LOCK MOV CR``. The AMD decoder can still decode Intel instructions.
"""
FORCE_RESERVED_NOP: int = 0x0000_0004
"""
Decode opcodes ``0F0D`` and ``0F18-0F1F`` as reserved-nop instructions (eg. :class:`iced_x86.Code.RESERVEDNOP_RM32_R32_0F1D`)
"""
UMOV: int = 0x0000_0008
"""
Decode ``UMOV`` instructions
"""
XBTS: int = 0x0000_0010
"""
Decode ``XBTS``/``IBTS``
"""
CMPXCHG486A: int = 0x0000_0020
"""
Decode ``0FA6``/``0FA7`` as ``CMPXCHG``
"""
OLD_FPU: int = 0x0000_0040
"""
Decode some old removed FPU instructions (eg. ``FRSTPM``)
"""
PCOMMIT: int = 0x0000_0080
"""
Decode ``PCOMMIT``
"""
LOADALL286: int = 0x0000_0100
"""
Decode 286 ``LOADALL`` (``0F04`` and ``0F05``)
"""
LOADALL386: int = 0x0000_0200
"""
Decode ``LOADALL386``
"""
CL1INVMB: int = 0x0000_0400
"""
Decode ``CL1INVMB``
"""
MOV_TR: int = 0x0000_0800
"""
Decode ``MOV r32,tr`` and ``MOV tr,r32``
"""
JMPE: int = 0x0000_1000
"""
Decode ``JMPE`` instructions
"""
NO_PAUSE: int = 0x0000_2000
"""
Don't decode ``PAUSE``, decode ``NOP`` instead
"""
NO_WBNOINVD: int = 0x0000_4000
"""
Don't decode ``WBNOINVD``, decode ``WBINVD`` instead
"""
NO_MPFX_0FBC: int = 0x0001_0000
"""
Don't decode ``TZCNT``, decode ``BSF`` instead
"""
NO_MPFX_0FBD: int = 0x0002_0000
"""
Don't decode ``LZCNT``, decode ``BSR`` instead
"""
NO_LAHF_SAHF_64: int = 0x0004_0000
"""
Don't decode ``LAHF`` and ``SAHF`` in 64-bit mode
"""
MPX: int = 0x0008_0000
"""
Decode ``MPX`` instructions
"""
CYRIX: int = 0x0010_0000
"""
: Decode most Cyrix instructions: ``FPU``, ``EMMI``, ``SMM``, ``DDI``
"""
CYRIX_SMINT_0F7E: int = 0x0020_0000
"""
Decode Cyrix ``SMINT 0F7E`` (Cyrix 6x86 or earlier)
"""
CYRIX_DMI: int = 0x0040_0000
"""
Decode Cyrix ``DMI`` instructions (AMD Geode GX/LX)
"""
ALTINST: int = 0x0080_0000
"""
Decode Centaur ``ALTINST``
"""



# SPDX-License-Identifier: MIT
# Copyright (C) 2018-present iced project and contributors

import sys
from setuptools import setup

try:
	from setuptools_rust import RustExtension, Strip
except:
	print()
	print("=============== MISSING BUILD TOOLS ===============")
	print("Missing setuptools-rust")
	print("Building iced-x86 requires `setuptools-rust` and Rust")
	print("setuptools-rust: pip3 install setuptools-rust")
	print("Rust: https://www.rust-lang.org/tools/install")
	print("=============== MISSING BUILD TOOLS ===============")
	print()
	raise

with open("README.md", "r", encoding="utf-8") as file:
	readme_md = file.read()

py_limited_api = any(arg == "--py-limited-api" or arg.startswith("--py-limited-api=") for arg in sys.argv)

setup(
	name="iced-x86",
	version="1.11.2",
	license="MIT",
	author_email="wtfsck@protonmail.com",
	author="wtfsck",
	description="iced-x86 is a blazing fast and correct x86/x64 disassembler, assembler and instruction decoder",
	long_description=readme_md,
	long_description_content_type="text/markdown",
	url="https://github.com/icedland/iced/tree/master/src/rust/iced-x86-py",
	platforms=["any"],
	python_requires="~=3.6",
	classifiers=[
		"Development Status :: 5 - Production/Stable",
		"Intended Audience :: Developers",
		"License :: OSI Approved :: MIT License",
		"Operating System :: MacOS :: MacOS X",
		"Operating System :: Microsoft :: Windows",
		"Operating System :: OS Independent",
		"Operating System :: POSIX",
		"Programming Language :: Python",
		"Programming Language :: Python :: 3",
		"Programming Language :: Python :: 3.6",
		"Programming Language :: Python :: 3.7",
		"Programming Language :: Python :: 3.8",
		"Programming Language :: Python :: 3.9",
		"Programming Language :: Python :: Implementation :: CPython",
		"Programming Language :: Python :: Implementation :: PyPy",
		"Programming Language :: Rust",
		"Topic :: Software Development :: Disassemblers",
		"Topic :: Software Development :: Libraries",
	],
	package_dir={"": "src"},
	packages=["iced_x86"],
	rust_extensions=[RustExtension("iced_x86._iced_x86_py", path="Cargo.toml", strip=Strip.All, py_limited_api=py_limited_api)],
	include_package_data=True,
	zip_safe=False,
)
